@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.42";
+our $VERSION = "1.43";
 
 use v5.14;
 use warnings;
@@ -47,6 +47,7 @@ use Getopt::EX::Hashed 1.05; {
     has parallel            => ' !  V    ' ;
     has filename            => ' !  H    ' ;
     has filename_format     => ' =s      ' , default => ': %s';
+    has ignore_empty        => ' !  I    ' , default => 0 ;
     has pages               => ' !       ' ;
     has up                  => ' :s U    ' ;
     has page                => ' :i P    ' , min => 0;
@@ -71,6 +72,7 @@ use Getopt::EX::Hashed 1.05; {
     has runlen              => ' =i      ' ;
     has pagebreak           => ' !       ' , default => 1 ;
     has border              => ' :s      ' ; has B => '' , action => sub { $_->border = '' } ;
+    has no_border           => '         ' , action => sub { $_->border = 'none' } ;
     has border_style        => ' =s   bs ' , default => 'box' ;
     has white_space         => ' !       ' , default => 2 ;
     has isolation           => ' !       ' , default => 2 ;
@@ -206,6 +208,10 @@ sub perform {
 
     my @files = $obj->read_files(@ARGV ? @ARGV : '-') or return 1;
 
+    if ($obj->ignore_empty) {
+	@files = grep { @{$_->{data}} > 0 } @files;
+    }
+
     if ($obj->table) {
 	my @lines = map { @{$_->{data}} } @files;
 	$obj->table_out(@lines);
